@@ -1,5 +1,6 @@
 import selectors
 import sys
+import time
 import threading
 from scalene.scalene_profiler import Scalene
 from typing import Optional, List, Tuple
@@ -17,7 +18,7 @@ def replacement_poll_selector(scalene: Scalene) -> None:
             self, timeout: Optional[float] = -1
         ) -> List[Tuple[selectors.SelectorKey, int]]:
             tident = threading.get_ident()
-            start_time = scalene.get_wallclock_time()
+            start_time = time.perf_counter()
             if not timeout or timeout < 0:
                 interval = sys.getswitchinterval()
             else:
@@ -28,7 +29,7 @@ def replacement_poll_selector(scalene: Scalene) -> None:
                 scalene.reset_thread_sleeping(tident)
                 if selected or timeout == 0:
                     return selected
-                end_time = scalene.get_wallclock_time()
+                end_time = time.perf_counter()
                 if timeout and timeout != -1:
                     if end_time - start_time >= timeout:
                         return []  # None
