@@ -10,17 +10,17 @@ try:
     from scalene.scalene_parseargs import ScaleneParseArgs
     from typing import Any
     import sys
-    import tempfile
 
     @magics_class
     class ScaleneMagics(Magics):  # type: ignore
         def run_code(self, args: ScaleneArguments, code: str) -> None:
+            import IPython
             # Create a file to hold the supplied code.
             # We encode the cell number in the string for later recovery.
             # The length of the history buffer lets us find the most recent string (this one).
-            filename = f"<ipython-input-{len(get_ipython().history_manager.input_hist_raw)-1}-profile>"
+            filename = f"<ipython-input-{len(IPython.get_ipython().history_manager.input_hist_raw)-1}-profile>"
             # Drop the first line (%%scalene).
-            newcode = '\n' + code
+            newcode = "\n" + code
             with open(filename, "w+") as tmpfile:
                 tmpfile.write(newcode)
             args.cpu_only = True  # full Scalene is not yet working, force to use CPU-only mode
