@@ -167,6 +167,7 @@ class Scalene:
     __malloc_lock_filename = Filename(f"/tmp/scalene-malloc-lock{os.getpid()}")
     __malloc_signal_position = 0
     __malloc_lastpos = bytearray(8)
+    __malloc_signal_mmap = None
     try:
         __malloc_signal_fd = open(__malloc_signal_filename, "r")
         os.unlink(__malloc_signal_fd.name)
@@ -371,6 +372,7 @@ class Scalene:
             Scalene.timer_signals = True
             t = threading.Thread(target=Scalene.timer_thang)
             t.start()
+            Scalene.start_signal_queues()
             return
         Scalene.start_signal_queues()
         # Set signal handlers for memory allocation and memcpy events.
@@ -702,11 +704,6 @@ class Scalene:
         this_frame: FrameType,
     ) -> List[Tuple[FrameType, int, FrameType]]:
         """Collects all stack frames that Scalene actually processes."""
-        if threading._active_limbo_lock.locked():  # type: ignore
-            # Avoids deadlock where a Scalene signal occurs
-            # in the middle of a critical section of the
-            # threading library
-            return []
         frames: List[Tuple[FrameType, int]] = [
             (
                 cast(
@@ -805,6 +802,8 @@ class Scalene:
 
     @staticmethod
     def read_malloc_mmap() -> bool:
+        if sys.platform == "win32":
+            return False
         return get_line_atomic.get_line_atomic(
             Scalene.__malloc_lock_mmap,
             Scalene.__malloc_signal_mmap,
@@ -999,6 +998,8 @@ class Scalene:
 
     @staticmethod
     def read_memcpy_mmap() -> bool:
+        if sys.platform == "win32":
+            return False
         return get_line_atomic.get_line_atomic(
             Scalene.__memcpy_lock_mmap,
             Scalene.__memcpy_signal_mmap,
